@@ -8,7 +8,7 @@
 
 void aa_change_hat_wrapper (int *ret, char **subprofile, unsigned long* magic_token, bool *verbose) {
   if(*verbose){
-	  Rprintf("Setting Apparmor Hat...\n");
+	  Rprintf("Setting AppArmor Hat...\n");
   }
   *ret = aa_change_hat (*subprofile,  *magic_token);
   if(*ret != 0){
